evvergames-commitlog Mailing List for Evver Games
Brought to you by:
rfulkerson
You can subscribe to this list here.
| 2007 |
Jan
|
Feb
|
Mar
|
Apr
|
May
|
Jun
(7) |
Jul
(142) |
Aug
(63) |
Sep
(24) |
Oct
(73) |
Nov
|
Dec
|
|---|---|---|---|---|---|---|---|---|---|---|---|---|
| 2008 |
Jan
|
Feb
|
Mar
(17) |
Apr
|
May
|
Jun
(53) |
Jul
(11) |
Aug
(14) |
Sep
|
Oct
|
Nov
|
Dec
|
| 2009 |
Jan
|
Feb
|
Mar
|
Apr
(2) |
May
(36) |
Jun
(3) |
Jul
(12) |
Aug
(18) |
Sep
|
Oct
|
Nov
(3) |
Dec
(4) |
| 2010 |
Jan
(7) |
Feb
|
Mar
|
Apr
|
May
|
Jun
|
Jul
|
Aug
|
Sep
|
Oct
(5) |
Nov
|
Dec
|
|
From: A c. l. f. E. G. <evv...@li...> - 2010-10-11 23:41:41
|
Revision: 793
http://evvergames.svn.sourceforge.net/evvergames/?rev=793&view=rev
Author: rfulkerson
Date: 2010-10-11 23:41:35 +0000 (Mon, 11 Oct 2010)
Log Message:
-----------
Fixed warnings
Modified Paths:
--------------
evvercards/trunk/src/com/evver/evvercards/Card.java
Modified: evvercards/trunk/src/com/evver/evvercards/Card.java
===================================================================
--- evvercards/trunk/src/com/evver/evvercards/Card.java 2010-10-11 23:33:23 UTC (rev 792)
+++ evvercards/trunk/src/com/evver/evvercards/Card.java 2010-10-11 23:41:35 UTC (rev 793)
@@ -61,6 +61,7 @@
private Integer value;
private Boolean shown;
private Boolean locked;
+ @SuppressWarnings("unchecked")
private Map props;
/**
@@ -90,6 +91,7 @@
* @param id the card ID
* @param baseURL the base properties URL
*/
+ @SuppressWarnings("unchecked")
public Card(Long id, String baseURL) {
if (id != null && baseURL != null) {
@@ -207,6 +209,7 @@
* Gets the card properties
* @return the card properties
*/
+ @SuppressWarnings("unchecked")
public Map getProperties() {
return this.props;
}
@@ -215,6 +218,7 @@
* Sets the card properties
* @param props the properties to set
*/
+ @SuppressWarnings("unchecked")
public void setProperties(Map props) {
this.props = props;
}
This was sent by the SourceForge.net collaborative development platform, the world's largest Open Source development site.
|
|
From: A c. l. f. E. G. <evv...@li...> - 2010-10-11 23:33:29
|
Revision: 792
http://evvergames.svn.sourceforge.net/evvergames/?rev=792&view=rev
Author: rfulkerson
Date: 2010-10-11 23:33:23 +0000 (Mon, 11 Oct 2010)
Log Message:
-----------
Fixed some warnings
Modified Paths:
--------------
evvergolf/trunk/.classpath
evvergolf/trunk/src/com/evver/games/golf/simulate/AIUtils.java
evvergolf/trunk/src/com/evver/games/golf/simulate/Simulator.java
Modified: evvergolf/trunk/.classpath
===================================================================
--- evvergolf/trunk/.classpath 2010-10-11 22:12:42 UTC (rev 791)
+++ evvergolf/trunk/.classpath 2010-10-11 23:33:23 UTC (rev 792)
@@ -3,5 +3,6 @@
<classpathentry kind="src" path="src"/>
<classpathentry kind="src" path="as3"/>
<classpathentry kind="con" path="org.eclipse.jdt.launching.JRE_CONTAINER"/>
+ <classpathentry combineaccessrules="false" kind="src" path="/evver-cards"/>
<classpathentry kind="output" path="bin"/>
</classpath>
Modified: evvergolf/trunk/src/com/evver/games/golf/simulate/AIUtils.java
===================================================================
--- evvergolf/trunk/src/com/evver/games/golf/simulate/AIUtils.java 2010-10-11 22:12:42 UTC (rev 791)
+++ evvergolf/trunk/src/com/evver/games/golf/simulate/AIUtils.java 2010-10-11 23:33:23 UTC (rev 792)
@@ -45,6 +45,7 @@
* @param control the current control
* @throws IllegalAccessException
*/
+ @SuppressWarnings("unchecked")
protected synchronized static void smartPlayerMove(final Player player, final Control control) throws IllegalAccessException {
//Initialize the player if needed
Modified: evvergolf/trunk/src/com/evver/games/golf/simulate/Simulator.java
===================================================================
--- evvergolf/trunk/src/com/evver/games/golf/simulate/Simulator.java 2010-10-11 22:12:42 UTC (rev 791)
+++ evvergolf/trunk/src/com/evver/games/golf/simulate/Simulator.java 2010-10-11 23:33:23 UTC (rev 792)
@@ -30,6 +30,7 @@
import com.evver.games.golf.GolfService;
public class Simulator extends GolfService {
+ private static final long serialVersionUID = 1L;
//The game constants
private static final float ITERATIONS = 100;
This was sent by the SourceForge.net collaborative development platform, the world's largest Open Source development site.
|
|
From: A c. l. f. E. G. <evv...@li...> - 2010-10-11 22:12:48
|
Revision: 791
http://evvergames.svn.sourceforge.net/evvergames/?rev=791&view=rev
Author: rfulkerson
Date: 2010-10-11 22:12:42 +0000 (Mon, 11 Oct 2010)
Log Message:
-----------
Renamed to evver-media
Modified Paths:
--------------
evvermedia/trunk/.project
Modified: evvermedia/trunk/.project
===================================================================
--- evvermedia/trunk/.project 2010-10-11 22:11:54 UTC (rev 790)
+++ evvermedia/trunk/.project 2010-10-11 22:12:42 UTC (rev 791)
@@ -1,6 +1,6 @@
<?xml version="1.0" encoding="UTF-8"?>
<projectDescription>
- <name>evvermedia</name>
+ <name>evver-media</name>
<comment></comment>
<projects>
</projects>
This was sent by the SourceForge.net collaborative development platform, the world's largest Open Source development site.
|
|
From: A c. l. f. E. G. <evv...@li...> - 2010-10-11 22:12:00
|
Revision: 790
http://evvergames.svn.sourceforge.net/evvergames/?rev=790&view=rev
Author: rfulkerson
Date: 2010-10-11 22:11:54 +0000 (Mon, 11 Oct 2010)
Log Message:
-----------
Renamed to evver-golf
Modified Paths:
--------------
evvergolf/trunk/.classpath
evvergolf/trunk/.project
evvergolf/trunk/.settings/org.eclipse.wst.common.component
Modified: evvergolf/trunk/.classpath
===================================================================
--- evvergolf/trunk/.classpath 2010-10-11 22:10:35 UTC (rev 789)
+++ evvergolf/trunk/.classpath 2010-10-11 22:11:54 UTC (rev 790)
@@ -3,6 +3,5 @@
<classpathentry kind="src" path="src"/>
<classpathentry kind="src" path="as3"/>
<classpathentry kind="con" path="org.eclipse.jdt.launching.JRE_CONTAINER"/>
- <classpathentry combineaccessrules="false" kind="src" path="/evvercards"/>
<classpathentry kind="output" path="bin"/>
</classpath>
Modified: evvergolf/trunk/.project
===================================================================
--- evvergolf/trunk/.project 2010-10-11 22:10:35 UTC (rev 789)
+++ evvergolf/trunk/.project 2010-10-11 22:11:54 UTC (rev 790)
@@ -1,6 +1,6 @@
<?xml version="1.0" encoding="UTF-8"?>
<projectDescription>
- <name>evvergolf</name>
+ <name>evver-golf</name>
<comment></comment>
<projects>
</projects>
Modified: evvergolf/trunk/.settings/org.eclipse.wst.common.component
===================================================================
--- evvergolf/trunk/.settings/org.eclipse.wst.common.component 2010-10-11 22:10:35 UTC (rev 789)
+++ evvergolf/trunk/.settings/org.eclipse.wst.common.component 2010-10-11 22:11:54 UTC (rev 790)
@@ -1,6 +1,6 @@
<?xml version="1.0" encoding="UTF-8"?>
<project-modules id="moduleCoreId" project-version="1.5.0">
- <wb-module deploy-name="evvergolf">
+ <wb-module deploy-name="evver-golf">
<wb-resource deploy-path="/" source-path="/src"/>
<wb-resource deploy-path="/" source-path="/as3"/>
</wb-module>
This was sent by the SourceForge.net collaborative development platform, the world's largest Open Source development site.
|
|
From: A c. l. f. E. G. <evv...@li...> - 2010-10-11 22:10:42
|
Revision: 789
http://evvergames.svn.sourceforge.net/evvergames/?rev=789&view=rev
Author: rfulkerson
Date: 2010-10-11 22:10:35 +0000 (Mon, 11 Oct 2010)
Log Message:
-----------
Renamed to evver-cards
Modified Paths:
--------------
evvercards/trunk/.project
evvercards/trunk/.settings/org.eclipse.wst.common.component
Modified: evvercards/trunk/.project
===================================================================
--- evvercards/trunk/.project 2010-01-11 06:43:28 UTC (rev 788)
+++ evvercards/trunk/.project 2010-10-11 22:10:35 UTC (rev 789)
@@ -1,6 +1,6 @@
<?xml version="1.0" encoding="UTF-8"?>
<projectDescription>
- <name>evvercards</name>
+ <name>evver-cards</name>
<comment></comment>
<projects>
</projects>
Modified: evvercards/trunk/.settings/org.eclipse.wst.common.component
===================================================================
--- evvercards/trunk/.settings/org.eclipse.wst.common.component 2010-01-11 06:43:28 UTC (rev 788)
+++ evvercards/trunk/.settings/org.eclipse.wst.common.component 2010-10-11 22:10:35 UTC (rev 789)
@@ -1,6 +1,6 @@
<?xml version="1.0" encoding="UTF-8"?>
<project-modules id="moduleCoreId" project-version="1.5.0">
- <wb-module deploy-name="evvercards">
+ <wb-module deploy-name="evver-cards">
<wb-resource deploy-path="/" source-path="/src"/>
<wb-resource deploy-path="/" source-path="/as3"/>
</wb-module>
This was sent by the SourceForge.net collaborative development platform, the world's largest Open Source development site.
|
|
From: A c. l. f. E. G. <evv...@li...> - 2010-01-11 06:43:35
|
Revision: 788
http://evvergames.svn.sourceforge.net/evvergames/?rev=788&view=rev
Author: rfulkerson
Date: 2010-01-11 06:43:28 +0000 (Mon, 11 Jan 2010)
Log Message:
-----------
Added reserved to description constructor
Modified Paths:
--------------
evvergolf/trunk/src/com/evver/games/golf/simulate/Simulator.java
Modified: evvergolf/trunk/src/com/evver/games/golf/simulate/Simulator.java
===================================================================
--- evvergolf/trunk/src/com/evver/games/golf/simulate/Simulator.java 2010-01-11 06:42:57 UTC (rev 787)
+++ evvergolf/trunk/src/com/evver/games/golf/simulate/Simulator.java 2010-01-11 06:43:28 UTC (rev 788)
@@ -66,7 +66,7 @@
try {
//Create the game and add the players
- Description gd = new Description(1L, "Golf", "Golfing for Food", 3, (int) SESSIONS);
+ Description gd = new Description(1L, "Golf", "Golfing for Food", 3, (int) SESSIONS, false);
Long gameId = createGame(bob, gd);
joinGame(bob, gameId);
joinGame(sue, gameId);
This was sent by the SourceForge.net collaborative development platform, the world's largest Open Source development site.
|
|
From: A c. l. f. E. G. <evv...@li...> - 2010-01-11 06:43:03
|
Revision: 787
http://evvergames.svn.sourceforge.net/evvergames/?rev=787&view=rev
Author: rfulkerson
Date: 2010-01-11 06:42:57 +0000 (Mon, 11 Jan 2010)
Log Message:
-----------
Added reserved to description constructor
Modified Paths:
--------------
evvercards/trunk/src/com/evver/evvercards/Description.java
evvercards/trunk/src/com/evver/evvercards/security/AuthorizedDescription.java
Modified: evvercards/trunk/src/com/evver/evvercards/Description.java
===================================================================
--- evvercards/trunk/src/com/evver/evvercards/Description.java 2010-01-06 06:38:43 UTC (rev 786)
+++ evvercards/trunk/src/com/evver/evvercards/Description.java 2010-01-11 06:42:57 UTC (rev 787)
@@ -52,15 +52,16 @@
* @param summary the user assigned summary
* @param max the maximum number of players
* @param len the user assigned length
+ * @param reserved is the game reserved
*/
- public Description (Long num, String title, String summary, Integer max, Integer len) {
+ public Description (Long num, String title, String summary, Integer max, Integer len, Boolean reserved) {
this.creationDate = new Date();
this.gamenum = num;
this.title = title;
this.summary = summary;
this.maxPlayers = max;
this.length = len;
- this.reserved = false;
+ this.reserved = reserved;
this.gameId = null;
}
Modified: evvercards/trunk/src/com/evver/evvercards/security/AuthorizedDescription.java
===================================================================
--- evvercards/trunk/src/com/evver/evvercards/security/AuthorizedDescription.java 2010-01-06 06:38:43 UTC (rev 786)
+++ evvercards/trunk/src/com/evver/evvercards/security/AuthorizedDescription.java 2010-01-11 06:42:57 UTC (rev 787)
@@ -39,9 +39,11 @@
* @param title the game title
* @param summary game summary
* @param len the number of sessions
+ * @param reserved is the game reserved
+ * @param pass the authentication password
*/
- public AuthorizedDescription(Long num, String title, String summary, Integer max, Integer len, char[] pass) {
- super(num, title, summary, max, len);
+ public AuthorizedDescription(Long num, String title, String summary, Integer max, Integer len, Boolean reserved, char[] pass) {
+ super(num, title, summary, max, len, reserved);
this.password = pass;
}
This was sent by the SourceForge.net collaborative development platform, the world's largest Open Source development site.
|
|
From: A c. l. f. E. G. <evv...@li...> - 2010-01-06 06:38:49
|
Revision: 786
http://evvergames.svn.sourceforge.net/evvergames/?rev=786&view=rev
Author: rfulkerson
Date: 2010-01-06 06:38:43 +0000 (Wed, 06 Jan 2010)
Log Message:
-----------
Changed Golf Game to EvverGolf
Modified Paths:
--------------
evvergolf/trunk/build.properties
evvergolf/trunk/build.xml
Modified: evvergolf/trunk/build.properties
===================================================================
--- evvergolf/trunk/build.properties 2010-01-06 06:34:31 UTC (rev 785)
+++ evvergolf/trunk/build.properties 2010-01-06 06:38:43 UTC (rev 786)
@@ -10,10 +10,10 @@
evvercards.location=../evvercards
# Manifest informaiton
-spec.title=Golf Game
+spec.title=EvverGolf
spec.version=0.8
spec.vendor=Evver
-impl.title=Golf Game
+impl.title=EvverGolf
impl.version=0.8
impl.vendor=Evver Games
lib.classpath=./evvergames-cards.jar
\ No newline at end of file
Modified: evvergolf/trunk/build.xml
===================================================================
--- evvergolf/trunk/build.xml 2010-01-06 06:34:31 UTC (rev 785)
+++ evvergolf/trunk/build.xml 2010-01-06 06:38:43 UTC (rev 786)
@@ -3,7 +3,7 @@
<!ENTITY common SYSTEM "common.xml">
]>
-<project name="golfgame" default="jar" basedir=".">
+<project name="evvergolf" default="jar" basedir=".">
<!-- Load the OS environment -->
<property environment="env"/>
@@ -15,7 +15,7 @@
<property name="FLEX_HOME" value="${env.FLEX_HOME}"/>
<!-- Set the project classpath -->
- <path id="golfgame.classpath">
+ <path id="evvergolf.classpath">
<pathelement location="bin"/>
<pathelement location="lib/evvergames-cards.jar"/>
</path>
@@ -30,7 +30,7 @@
<available file="${evvercards.location}" property="evvercards.exists"/>
</target>
- <!-- Build projects which golfgame depends upon -->
+ <!-- Build projects which evvergolf depends upon -->
<target name="build-evvercards-jar" depends="init" if="evvercards.exists">
<ant antfile="${evvercards.location}/build.xml" target="jar" inheritAll="false">
<propertyset>
@@ -40,16 +40,16 @@
<copy file="${evvercards.location}/dist/evvergames-cards.jar" tofile="lib/evvergames-cards.jar"/>
</target>
- <!-- Build the golfgame and sub-projects -->
+ <!-- Build the evvergolf and sub-projects -->
<target name="build" depends="build-evvercards-jar">
<echo message="${ant.project.name}: ${ant.file}"/>
<javac destdir="bin" debug="${debug}" debuglevel="${debuglevel}" source="${source}" target="${target}">
<src path="src"/>
- <classpath refid="golfgame.classpath"/>
+ <classpath refid="evvergolf.classpath"/>
</javac>
</target>
- <!-- Create golfgame binary library -->
+ <!-- Create evvergolf binary library -->
<target name="jar" depends="build">
<!-- Create the manifest file -->
@@ -69,7 +69,7 @@
<jar jarfile="dist/evvergames-golf.jar" manifest="bin/META-INF/MANIFEST.MF" basedir="bin"/>
</target>
- <!-- Build projects which golfgame depends upon -->
+ <!-- Build projects which evvergolf depends upon -->
<target name="build-evvercards-swc" depends="init" if="evvercards.exists">
<ant antfile="${evvercards.location}/build.xml" target="swc" inheritAll="false">
<propertyset>
@@ -80,11 +80,11 @@
</target>
- <!-- Create golfgame swc library -->
+ <!-- Create evvergolf swc library -->
<target name="swc" depends="build-evvercards-swc">
<!-- Define the component compiler task -->
- <taskdef name="compc" classname="flex.ant.CompcTask" classpath="${FLEX_HOME}/ant/lib/flexTasks.jar" />
+ <taskdef name="compc" classname="flex.ant.CompcTask" classpath="${FLEX_HOME}/ant/lib/flexTasks.jar"/>
<!-- Create a list of our classes -->
<pathconvert property="as3classes" pathsep=" ">
@@ -116,7 +116,7 @@
excludes="**/.svn, bin/**, .settings/**, dist/evvergolf*.zip, .classpath, .project"/>
</target>
- <!-- Clean the golfgame -->
+ <!-- Clean evvergolf -->
<target name="clean">
<delete dir="bin"/>
<delete dir="dist"/>
This was sent by the SourceForge.net collaborative development platform, the world's largest Open Source development site.
|
|
From: A c. l. f. E. G. <evv...@li...> - 2010-01-06 06:34:37
|
Revision: 785
http://evvergames.svn.sourceforge.net/evvergames/?rev=785&view=rev
Author: rfulkerson
Date: 2010-01-06 06:34:31 +0000 (Wed, 06 Jan 2010)
Log Message:
-----------
Changed secured to reserved
Modified Paths:
--------------
evvercards/trunk/as3/com/evver/evvercards/Description.as
Modified: evvercards/trunk/as3/com/evver/evvercards/Description.as
===================================================================
--- evvercards/trunk/as3/com/evver/evvercards/Description.as 2010-01-06 05:03:59 UTC (rev 784)
+++ evvercards/trunk/as3/com/evver/evvercards/Description.as 2010-01-06 06:34:31 UTC (rev 785)
@@ -33,7 +33,7 @@
private var _maxPlayers:int;
private var _length:int;
private var _gameId:int;
- private var _secured:Boolean;
+ private var _reserved:Boolean;
/**
* Constructs the game Description class
@@ -130,12 +130,12 @@
* Is the game secured
* @return the game is secured
*/
- public function get secured():Boolean {
- return this._secured;
+ public function get reserved():Boolean {
+ return this._reserved;
}
- public function set secured(secured:Boolean):void {
- this._secured = secured;
+ public function set reserved(reserved:Boolean):void {
+ this._reserved = reserved;
}
}
This was sent by the SourceForge.net collaborative development platform, the world's largest Open Source development site.
|
|
From: A c. l. f. E. G. <evv...@li...> - 2010-01-06 05:04:05
|
Revision: 784
http://evvergames.svn.sourceforge.net/evvergames/?rev=784&view=rev
Author: rfulkerson
Date: 2010-01-06 05:03:59 +0000 (Wed, 06 Jan 2010)
Log Message:
-----------
Fixed project name
Modified Paths:
--------------
evvergolf/trunk/.settings/org.eclipse.wst.common.component
Modified: evvergolf/trunk/.settings/org.eclipse.wst.common.component
===================================================================
--- evvergolf/trunk/.settings/org.eclipse.wst.common.component 2010-01-04 05:28:25 UTC (rev 783)
+++ evvergolf/trunk/.settings/org.eclipse.wst.common.component 2010-01-06 05:03:59 UTC (rev 784)
@@ -1,6 +1,6 @@
<?xml version="1.0" encoding="UTF-8"?>
<project-modules id="moduleCoreId" project-version="1.5.0">
- <wb-module deploy-name="golfgame">
+ <wb-module deploy-name="evvergolf">
<wb-resource deploy-path="/" source-path="/src"/>
<wb-resource deploy-path="/" source-path="/as3"/>
</wb-module>
This was sent by the SourceForge.net collaborative development platform, the world's largest Open Source development site.
|
|
From: A c. l. f. E. G. <evv...@li...> - 2010-01-04 05:28:31
|
Revision: 783
http://evvergames.svn.sourceforge.net/evvergames/?rev=783&view=rev
Author: rfulkerson
Date: 2010-01-04 05:28:25 +0000 (Mon, 04 Jan 2010)
Log Message:
-----------
Changed project name from golfgame to evvergolf
Added Paths:
-----------
evvergolf/
Removed Paths:
-------------
golfgame/
This was sent by the SourceForge.net collaborative development platform, the world's largest Open Source development site.
|
|
From: A c. l. f. E. G. <evv...@li...> - 2010-01-04 05:27:10
|
Revision: 782
http://evvergames.svn.sourceforge.net/evvergames/?rev=782&view=rev
Author: rfulkerson
Date: 2010-01-04 05:27:04 +0000 (Mon, 04 Jan 2010)
Log Message:
-----------
Changed project name from golfgame to evvergolf
Modified Paths:
--------------
golfgame/trunk/.project
Modified: golfgame/trunk/.project
===================================================================
--- golfgame/trunk/.project 2009-12-29 06:04:24 UTC (rev 781)
+++ golfgame/trunk/.project 2010-01-04 05:27:04 UTC (rev 782)
@@ -1,6 +1,6 @@
<?xml version="1.0" encoding="UTF-8"?>
<projectDescription>
- <name>golfgame</name>
+ <name>evvergolf</name>
<comment></comment>
<projects>
</projects>
This was sent by the SourceForge.net collaborative development platform, the world's largest Open Source development site.
|
|
From: A c. l. f. E. G. <evv...@li...> - 2009-12-29 06:04:33
|
Revision: 781
http://evvergames.svn.sourceforge.net/evvergames/?rev=781&view=rev
Author: rfulkerson
Date: 2009-12-29 06:04:24 +0000 (Tue, 29 Dec 2009)
Log Message:
-----------
Clarified naming while working on XML
Modified Paths:
--------------
evvercards/trunk/src/com/evver/evvercards/Session.java
evvercards/trunk/src/com/evver/evvercards/service/AbstractControl.java
evvercards/trunk/src/com/evver/evvercards/service/AbstractService.java
evvercards/trunk/src/com/evver/evvercards/service/BasicControl.java
evvercards/trunk/src/com/evver/evvercards/service/Control.java
evvercards/trunk/src/com/evver/evvercards/service/Service.java
golfgame/trunk/src/com/evver/games/golf/GolfControl.java
golfgame/trunk/src/com/evver/games/golf/simulate/AIUtils.java
Modified: evvercards/trunk/src/com/evver/evvercards/Session.java
===================================================================
--- evvercards/trunk/src/com/evver/evvercards/service/AbstractControl.java 2009-12-28 05:43:49 UTC (rev 780)
+++ evvercards/trunk/src/com/evver/evvercards/service/AbstractControl.java 2009-12-29 06:04:24 UTC (rev 781)
@@ -301,7 +301,7 @@
//NOTE: We do not 'game.setEnded' here, as this must be done in end()
//Check the the current session is complete and all session has been played
- boolean sessComplete = isSessionComplete(game.currentSession());
+ boolean sessComplete = isSessionCompleted(game.currentSession());
int gameLength = game.getLength().intValue();
int sessNumber = game.getSessions().size();
@@ -415,7 +415,7 @@
session.setHand(p, hand);
board.setInitialized(true);
session.setBoard(p, board);
- session.setState(p, Session.STATE_INITIALIZED);
+ session.setState(p, Session.STATE_STARTED);
} catch (IllegalAccessException e) { e.printStackTrace(); }
}
@@ -455,7 +455,7 @@
* @param session the session
* @return is session complete
*/
- protected synchronized boolean isSessionComplete(Session session) {
+ protected synchronized boolean isSessionCompleted(Session session) {
//Check if all boards have been revealed
boolean complete = session.getBoards().size() > 0;
Modified: evvercards/trunk/src/com/evver/evvercards/service/AbstractService.java
===================================================================
--- evvercards/trunk/src/com/evver/evvercards/service/AbstractService.java 2009-12-28 05:43:49 UTC (rev 780)
+++ evvercards/trunk/src/com/evver/evvercards/service/AbstractService.java 2009-12-29 06:04:24 UTC (rev 781)
@@ -378,20 +378,20 @@
}
/**
- * @see com.evver.evvercards.service.Control#isSessionInitialized(Player)
+ * @see com.evver.evvercards.service.Control#isSessionStarted(Player)
*/
- public Boolean isSessionInitialized(Long id, Player p) throws IllegalAccessException {
+ public Boolean isSessionStarted(Long id, Player p) throws IllegalAccessException {
if (getControl(id) != null)
- return getControl(id).isSessionInitialized(p);
+ return getControl(id).isSessionStarted(p);
else return null;
}
/**
- * @see com.evver.evvercards.service.Control#isSessionComplete(Player)
+ * @see com.evver.evvercards.service.Control#isSessionCompleted(Player)
*/
- public Boolean isSessionComplete(Long id, Player p) throws IllegalAccessException {
+ public Boolean isSessionCompleted(Long id, Player p) throws IllegalAccessException {
if (getControl(id) != null)
- return getControl(id).isSessionComplete(p);
+ return getControl(id).isSessionCompleted(p);
else return null;
}
Modified: evvercards/trunk/src/com/evver/evvercards/service/BasicControl.java
===================================================================
--- evvercards/trunk/src/com/evver/evvercards/service/BasicControl.java 2009-12-28 05:43:49 UTC (rev 780)
+++ evvercards/trunk/src/com/evver/evvercards/service/BasicControl.java 2009-12-29 06:04:24 UTC (rev 781)
@@ -147,16 +147,16 @@
}
/**
- * @see com.evver.evvercards.service.Control#isSessionInitialized(com.evver.evvercards.Player)
+ * @see com.evver.evvercards.service.Control#isSessionStarted(com.evver.evvercards.Player)
*/
- public synchronized Boolean isSessionInitialized(Player p) throws IllegalAccessException {
- return getSessionState(p, p.getId()) == Session.STATE_INITIALIZED;
+ public synchronized Boolean isSessionStarted(Player p) throws IllegalAccessException {
+ return getSessionState(p, p.getId()) == Session.STATE_STARTED;
}
/**
- * @see com.evver.evvercards.service.Control#isSessionComplete(Player)
+ * @see com.evver.evvercards.service.Control#isSessionCompleted(Player)
*/
- public synchronized Boolean isSessionComplete(Player p) throws IllegalAccessException {
+ public synchronized Boolean isSessionCompleted(Player p) throws IllegalAccessException {
return getSessionState(p, p.getId()) == Session.STATE_COMPLETED;
}
@@ -209,7 +209,7 @@
List<Session> sessions = game.getSessions();
for (Session session : sessions) {
//Prevent new session from being added
- if (isSessionComplete(session)) {
+ if (isSessionCompleted(session)) {
Score score = session.getScore(player);
gameScore.addValue(score.getTotalScore());
}
@@ -250,7 +250,7 @@
evaluateSession(session);
// Is the session complete
- boolean sessionComplete = isSessionComplete(session);
+ boolean sessionComplete = isSessionCompleted(session);
//Send events when the session is complete
if (sessionComplete) {
Modified: evvercards/trunk/src/com/evver/evvercards/service/Control.java
===================================================================
--- evvercards/trunk/src/com/evver/evvercards/service/Service.java 2009-12-28 05:43:49 UTC (rev 780)
+++ evvercards/trunk/src/com/evver/evvercards/service/Service.java 2009-12-29 06:04:24 UTC (rev 781)
@@ -274,14 +274,14 @@
* @param id the game id
* @return session is initialized
*/
- public Boolean isSessionInitialized(Long id, Player p) throws IllegalAccessException;
+ public Boolean isSessionStarted(Long id, Player p) throws IllegalAccessException;
/**
* Is the current session complete
* @param id the game id
* @return session is complete
*/
- public Boolean isSessionComplete(Long id, Player p) throws IllegalAccessException;
+ public Boolean isSessionCompleted(Long id, Player p) throws IllegalAccessException;
/**
* Gets the number of sessions, including the current and all previous sessions
Modified: golfgame/trunk/src/com/evver/games/golf/GolfControl.java
===================================================================
--- golfgame/trunk/src/com/evver/games/golf/simulate/AIUtils.java 2009-12-28 05:43:49 UTC (rev 780)
+++ golfgame/trunk/src/com/evver/games/golf/simulate/AIUtils.java 2009-12-29 06:04:24 UTC (rev 781)
@@ -48,14 +48,14 @@
protected synchronized static void smartPlayerMove(final Player player, final Control control) throws IllegalAccessException {
//Initialize the player if needed
- if (!control.isSessionInitialized(player).booleanValue()) {
+ if (!control.isSessionStarted(player).booleanValue()) {
initializePlayer(player, control);
}
//Ensure the session was initialized
//NOTE: The session will only be uninitialized after the
//NOTE: game has ended and the embedded control becomes null
- Boolean initialized = control.isSessionInitialized(player);
+ Boolean initialized = control.isSessionStarted(player);
if (initialized != null && initialized.booleanValue()) {
//Get the discard
This was sent by the SourceForge.net collaborative development platform, the world's largest Open Source development site.
|
|
From: A c. l. f. E. G. <evv...@li...> - 2009-12-28 05:43:58
|
Revision: 780
http://evvergames.svn.sourceforge.net/evvergames/?rev=780&view=rev
Author: rfulkerson
Date: 2009-12-28 05:43:49 +0000 (Mon, 28 Dec 2009)
Log Message:
-----------
Changed isGameComplete to isGameCompleted, to match isGameStarted
Modified Paths:
--------------
golfgame/trunk/src/com/evver/games/golf/GolfControl.java
golfgame/trunk/src/com/evver/games/golf/simulate/Simulator.java
Modified: golfgame/trunk/src/com/evver/games/golf/GolfControl.java
===================================================================
--- golfgame/trunk/src/com/evver/games/golf/GolfControl.java 2009-12-28 05:42:43 UTC (rev 779)
+++ golfgame/trunk/src/com/evver/games/golf/GolfControl.java 2009-12-28 05:43:49 UTC (rev 780)
@@ -212,7 +212,7 @@
public synchronized Boolean start(Player p) throws IllegalAccessException {
//Ensure the game has not already ended
- if (isGameComplete())
+ if (isGameCompleted())
throw new IllegalAccessException("Sorry " + p + ", but the game has ended!");
//Get the current session
@@ -273,7 +273,7 @@
//Handle the user ending during their turn
//This must happen before the player is removed
//to ensure accurate results are returned
- if (p.equals(getCurrentPlayer()) && !isGameComplete()) {
+ if (p.equals(getCurrentPlayer()) && !isGameCompleted()) {
if (getHeldCards(p).size() > 0) {
Card card = drawFromHand(p, 0);
discardCard(p, card);
@@ -298,7 +298,7 @@
//Replace this player with an AI player, as long as other real players exist, otherwise remove player
Boolean bool = null;
- if (playerIndex != -1 && realPlayers > 0 && !isGameComplete()) {
+ if (playerIndex != -1 && realPlayers > 0 && !isGameCompleted()) {
players.set(playerIndex, new GolfPlayer(p.getId(), this));
} else bool = removePlayer(p);
@@ -323,7 +323,7 @@
if (sessionComplete) {
//Send scores when the game is complete
- if (isGameComplete()) {
+ if (isGameCompleted()) {
//Create a list of player scores
ArrayList<Score> scores = new ArrayList<Score>();
Modified: golfgame/trunk/src/com/evver/games/golf/simulate/Simulator.java
===================================================================
--- golfgame/trunk/src/com/evver/games/golf/simulate/Simulator.java 2009-12-28 05:42:43 UTC (rev 779)
+++ golfgame/trunk/src/com/evver/games/golf/simulate/Simulator.java 2009-12-28 05:43:49 UTC (rev 780)
@@ -138,7 +138,7 @@
try {
//Loop through simulated player moves
- while (!isGameComplete(id)) {
+ while (!isGameCompleted(id)) {
//Start a new session each time the current is complete
if (getCurrentUserID(id) == null) {
This was sent by the SourceForge.net collaborative development platform, the world's largest Open Source development site.
|
|
From: A c. l. f. E. G. <evv...@li...> - 2009-12-28 05:42:54
|
Revision: 779
http://evvergames.svn.sourceforge.net/evvergames/?rev=779&view=rev
Author: rfulkerson
Date: 2009-12-28 05:42:43 +0000 (Mon, 28 Dec 2009)
Log Message:
-----------
Changed isGameComplete to isGameCompleted, to match isGameStarted
Modified Paths:
--------------
evvercards/trunk/src/com/evver/evvercards/service/AbstractControl.java
evvercards/trunk/src/com/evver/evvercards/service/AbstractService.java
evvercards/trunk/src/com/evver/evvercards/service/Control.java
evvercards/trunk/src/com/evver/evvercards/service/Service.java
Modified: evvercards/trunk/src/com/evver/evvercards/service/AbstractControl.java
===================================================================
--- evvercards/trunk/src/com/evver/evvercards/service/AbstractControl.java 2009-12-28 05:36:01 UTC (rev 778)
+++ evvercards/trunk/src/com/evver/evvercards/service/AbstractControl.java 2009-12-28 05:42:43 UTC (rev 779)
@@ -295,9 +295,9 @@
}
/**
- * @see com.evver.evvercards.service.Control#isGameComplete()
+ * @see com.evver.evvercards.service.Control#isGameCompleted()
*/
- public synchronized Boolean isGameComplete() throws IllegalAccessException {
+ public synchronized Boolean isGameCompleted() throws IllegalAccessException {
//NOTE: We do not 'game.setEnded' here, as this must be done in end()
//Check the the current session is complete and all session has been played
@@ -320,7 +320,7 @@
//Create the status object and set the status basics
Status status = new Status();
status.setGameStarted(isGameStarted());
- status.setGameComplete(isGameComplete());
+ status.setGameComplete(isGameCompleted());
status.setCurrentPlayer(getCurrentPlayer());
status.setDiscardCard(getDiscardCard(p));
status.setSourceCard(getSourceCard(p));
Modified: evvercards/trunk/src/com/evver/evvercards/service/AbstractService.java
===================================================================
--- evvercards/trunk/src/com/evver/evvercards/service/AbstractService.java 2009-12-28 05:36:01 UTC (rev 778)
+++ evvercards/trunk/src/com/evver/evvercards/service/AbstractService.java 2009-12-28 05:42:43 UTC (rev 779)
@@ -198,11 +198,11 @@
}
/**
- * @see com.evver.evvercards.service.Control#isGameComplete()
+ * @see com.evver.evvercards.service.Control#isGameCompleted()
*/
- public Boolean isGameComplete(Long id) throws IllegalAccessException {
+ public Boolean isGameCompleted(Long id) throws IllegalAccessException {
if (getControl(id) != null)
- return getControl(id).isGameComplete();
+ return getControl(id).isGameCompleted();
else return null;
}
Modified: evvercards/trunk/src/com/evver/evvercards/service/Control.java
===================================================================
--- evvercards/trunk/src/com/evver/evvercards/service/Control.java 2009-12-28 05:36:01 UTC (rev 778)
+++ evvercards/trunk/src/com/evver/evvercards/service/Control.java 2009-12-28 05:42:43 UTC (rev 779)
@@ -65,7 +65,7 @@
* Is the game complete
* @return game over
*/
- public Boolean isGameComplete() throws IllegalAccessException;
+ public Boolean isGameCompleted() throws IllegalAccessException;
/**
* Gets the current player user ID
Modified: evvercards/trunk/src/com/evver/evvercards/service/Service.java
===================================================================
--- evvercards/trunk/src/com/evver/evvercards/service/Service.java 2009-12-28 05:36:01 UTC (rev 778)
+++ evvercards/trunk/src/com/evver/evvercards/service/Service.java 2009-12-28 05:42:43 UTC (rev 779)
@@ -65,7 +65,7 @@
* @param id the game id
* @return game over
*/
- public Boolean isGameComplete(Long id) throws IllegalAccessException;
+ public Boolean isGameCompleted(Long id) throws IllegalAccessException;
/**
* Gets the current player user ID
This was sent by the SourceForge.net collaborative development platform, the world's largest Open Source development site.
|
|
From: A c. l. f. E. G. <evv...@li...> - 2009-12-28 05:36:09
|
Revision: 778
http://evvergames.svn.sourceforge.net/evvergames/?rev=778&view=rev
Author: rfulkerson
Date: 2009-12-28 05:36:01 +0000 (Mon, 28 Dec 2009)
Log Message:
-----------
Modified a service to access a control via game id
Modified Paths:
--------------
evvercards/trunk/src/com/evver/evvercards/service/AbstractService.java
evvercards/trunk/src/com/evver/evvercards/service/Service.java
golfgame/trunk/src/com/evver/games/golf/simulate/Simulator.java
Modified: evvercards/trunk/src/com/evver/evvercards/service/AbstractService.java
===================================================================
--- evvercards/trunk/src/com/evver/evvercards/service/AbstractService.java 2009-11-16 04:47:17 UTC (rev 777)
+++ evvercards/trunk/src/com/evver/evvercards/service/AbstractService.java 2009-12-28 05:36:01 UTC (rev 778)
@@ -52,9 +52,6 @@
//The service listeners
protected CopyOnWriteArrayList<EventListener> serviceListeners = null;
- //The game id
- protected Long id = null;
-
/**
* Construct the remote handler
*/
@@ -130,7 +127,7 @@
*/
public Long createGame(Player p, Description gd) throws IllegalAccessException {
if (getEngine() != null) {
- id = getEngine().createGame(p, gd);
+ Long id = getEngine().createGame(p, gd);
sendEvent(id, GAME_CREATED, gd);
return id;
} else return null;
@@ -143,8 +140,7 @@
if (getEngine() != null) {
Boolean bool = getEngine().joinGame(p, id);
if (bool) {
- this.id = id;
- sendEvent(id, GAME_JOINED, getGameDescription());
+ sendEvent(id, GAME_JOINED, getGameDescription(id));
}
return bool;
}
@@ -152,18 +148,9 @@
}
/**
- * @see com.evver.evvercards.service.Control#getGameID()
- */
- public Long getGameID() {
- if (getControl(id) != null)
- return getControl(id).getGameID();
- else return null;
- }
-
- /**
* @see com.evver.evvercards.service.Control#getGameDescription()
*/
- public Description getGameDescription() {
+ public Description getGameDescription(Long id) {
if (getControl(id) != null)
return getControl(id).getGameDescription();
else return null;
@@ -181,7 +168,7 @@
/**
* @see com.evver.evvercards.service.Control#start(Player p)
*/
- public Boolean start(Player p) throws IllegalAccessException {
+ public Boolean start(Long id, Player p) throws IllegalAccessException {
if (getControl(id) != null)
return getControl(id).start(p);
else return null;
@@ -190,7 +177,7 @@
/**
* @see com.evver.evvercards.service.Control#end(Player p)
*/
- public Boolean end(Player p) throws IllegalAccessException {
+ public Boolean end(Long id, Player p) throws IllegalAccessException {
if (getControl(id) != null) {
Boolean bool = getControl(id).end(p);
Game game = getControl(id).getGame();
@@ -204,7 +191,7 @@
/**
* @see com.evver.evvercards.service.Control#isGameStarted()
*/
- public Boolean isGameStarted() throws IllegalAccessException {
+ public Boolean isGameStarted(Long id) throws IllegalAccessException {
if (getControl(id) != null)
return getControl(id).isGameStarted();
else return null;
@@ -213,7 +200,7 @@
/**
* @see com.evver.evvercards.service.Control#isGameComplete()
*/
- public Boolean isGameComplete() throws IllegalAccessException {
+ public Boolean isGameComplete(Long id) throws IllegalAccessException {
if (getControl(id) != null)
return getControl(id).isGameComplete();
else return null;
@@ -222,7 +209,7 @@
/**
* @see com.evver.evvercards.service.Control#getGameStatus(Player)
*/
- public Status getGameStatus(Player p) throws IllegalAccessException {
+ public Status getGameStatus(Long id, Player p) throws IllegalAccessException {
if (getControl(id) != null) {
return getControl(id).getGameStatus(p);
} else return null;
@@ -231,7 +218,7 @@
/**
* @see com.evver.evvercards.service.Control#getDiscardCard()
*/
- public Card getDiscardCard(Player p) throws IllegalAccessException {
+ public Card getDiscardCard(Long id, Player p) throws IllegalAccessException {
if (getControl(id) != null)
return getControl(id).getDiscardCard(p);
else return null;
@@ -240,7 +227,7 @@
/**
* @see com.evver.evvercards.service.Control#getSourceCard()
*/
- public Card getSourceCard(Player p) throws IllegalAccessException {
+ public Card getSourceCard(Long id, Player p) throws IllegalAccessException {
if (getControl(id) != null)
return getControl(id).getSourceCard(p);
else return null;
@@ -249,7 +236,7 @@
/**
* @see com.evver.evvercards.service.Control#getHeldCards(Long id, Player p)
*/
- public List<Card> getHeldCards(Player p) throws IllegalAccessException {
+ public List<Card> getHeldCards(Long id, Player p) throws IllegalAccessException {
if (getControl(id) != null)
return getControl(id).getHeldCards(p);
else return null;
@@ -258,7 +245,7 @@
/**
* @see com.evver.evvercards.service.Control#getBoardCard(Player, Position)
*/
- public Card getBoardCard(Player p, Position pos) throws IllegalAccessException {
+ public Card getBoardCard(Long id, Player p, Position pos) throws IllegalAccessException {
if (getControl(id) != null)
return getControl(id).getBoardCard(p, pos);
else return null;
@@ -267,7 +254,7 @@
/**
* @see com.evver.evvercards.service.Control#getBoardPosition(Player, Card)
*/
- public Position getBoardPosition(Player p, Card card) throws IllegalAccessException {
+ public Position getBoardPosition(Long id, Player p, Card card) throws IllegalAccessException {
if (getControl(id) != null)
return getControl(id).getBoardPosition(p, card);
else return null;
@@ -276,7 +263,7 @@
/**
* @see com.evver.evvercards.service.Control#getBoardPositions(Player)
*/
- public List<Position> getBoardPositions(Player p) throws IllegalAccessException {
+ public List<Position> getBoardPositions(Long id, Player p) throws IllegalAccessException {
if (getControl(id) != null)
return getControl(id).getBoardPositions(p);
else return null;
@@ -285,7 +272,7 @@
/**
* @see com.evver.evvercards.service.Control#drawFromDiscard(Player)
*/
- public Card drawFromDiscard(Player p) throws IllegalAccessException {
+ public Card drawFromDiscard(Long id, Player p) throws IllegalAccessException {
if (getControl(id) != null)
return getControl(id).drawFromDiscard(p);
else return null;
@@ -294,7 +281,7 @@
/**
* @see com.evver.evvercards.service.Control#drawFromSource(Player)
*/
- public Card drawFromSource(Player p) throws IllegalAccessException {
+ public Card drawFromSource(Long id, Player p) throws IllegalAccessException {
if (getControl(id) != null)
return getControl(id).drawFromSource(p);
else return null;
@@ -303,7 +290,7 @@
/**
* @see com.evver.evvercards.service.Control#drawFromHand(Player, Integer)
*/
- public Card drawFromHand(Player p, Integer index) throws IllegalAccessException {
+ public Card drawFromHand(Long id, Player p, Integer index) throws IllegalAccessException {
if (getControl(id) != null)
return getControl(id).drawFromHand(p, index);
else return null;
@@ -312,7 +299,7 @@
/**
* @see com.evver.evvercards.service.Control#playCard(Player, Position, Card)
*/
- public Boolean playCard(Player p, Position pos, Card card) throws IllegalAccessException {
+ public Boolean playCard(Long id, Player p, Position pos, Card card) throws IllegalAccessException {
if (getControl(id) != null) {
return getControl(id).playCard(p, pos, card);
} else return null;
@@ -321,7 +308,7 @@
/**
* @see com.evver.evvercards.service.Control#discardCard(Player, Card)
*/
- public Boolean discardCard(Player p, Card card) throws IllegalAccessException {
+ public Boolean discardCard(Long id, Player p, Card card) throws IllegalAccessException {
if (getControl(id) != null) {
return getControl(id).discardCard(p, card);
} else return null;
@@ -330,7 +317,7 @@
/**
* @see com.evver.evvercards.service.Control#holdCard(Player, Card, Integer)
*/
- public Boolean holdCard(Player p, Card card, Integer index) throws IllegalAccessException {
+ public Boolean holdCard(Long id, Player p, Card card, Integer index) throws IllegalAccessException {
if (getControl(id) != null) {
return getControl(id).holdCard(p, card, index);
} else return null;
@@ -339,7 +326,7 @@
/**
* @see com.evver.evvercards.service.Control#revealCard(Player, Position)
*/
- public Card revealCard(Player p, Position pos) throws IllegalAccessException {
+ public Card revealCard(Long id, Player p, Position pos) throws IllegalAccessException {
if (getControl(id) != null)
return getControl(id).revealCard(p, pos);
else return null;
@@ -348,7 +335,7 @@
/**
* @see com.evver.evvercards.service.Control#hideCard(Player, Position)
*/
- public Boolean hideCard(Player p, Position pos) throws IllegalAccessException {
+ public Boolean hideCard(Long id, Player p, Position pos) throws IllegalAccessException {
if (getControl(id) != null)
return getControl(id).hideCard(p, pos);
else return null;
@@ -357,7 +344,7 @@
/**
* @see com.evver.evvercards.service.Control#isPositionRevealed(Player, Position)
*/
- public Boolean isPositionRevealed(Player p, Position pos) throws IllegalAccessException {
+ public Boolean isPositionRevealed(Long id, Player p, Position pos) throws IllegalAccessException {
if (getControl(id) != null)
return getControl(id).isPositionRevealed(p, pos);
else return null;
@@ -366,7 +353,7 @@
/**
* @see com.evver.evvercards.service.Control#isPositionLocked(Player, Position)
*/
- public Boolean isPositionLocked(Player p, Position pos) throws IllegalAccessException {
+ public Boolean isPositionLocked(Long id, Player p, Position pos) throws IllegalAccessException {
if (getControl(id) != null)
return getControl(id).isPositionLocked(p, pos);
else return null;
@@ -375,7 +362,7 @@
/**
* @see com.evver.evvercards.service.Control#sendMessage(Player, Message)
*/
- public Boolean sendMessage(Player p, Message m) throws IllegalAccessException {
+ public Boolean sendMessage(Long id, Player p, Message m) throws IllegalAccessException {
if (getControl(id) != null)
return getControl(id).sendMessage(p, m);
else return null;
@@ -384,7 +371,7 @@
/**
* @see com.evver.evvercards.service.Control#sendSignal(Player, Object)
*/
- public Boolean sendSignal(Player p, Object signal) throws IllegalAccessException {
+ public Boolean sendSignal(Long id, Player p, Object signal) throws IllegalAccessException {
if (getControl(id) != null)
return getControl(id).sendSignal(p, signal);
else return null;
@@ -393,7 +380,7 @@
/**
* @see com.evver.evvercards.service.Control#isSessionInitialized(Player)
*/
- public Boolean isSessionInitialized(Player p) throws IllegalAccessException {
+ public Boolean isSessionInitialized(Long id, Player p) throws IllegalAccessException {
if (getControl(id) != null)
return getControl(id).isSessionInitialized(p);
else return null;
@@ -402,7 +389,7 @@
/**
* @see com.evver.evvercards.service.Control#isSessionComplete(Player)
*/
- public Boolean isSessionComplete(Player p) throws IllegalAccessException {
+ public Boolean isSessionComplete(Long id, Player p) throws IllegalAccessException {
if (getControl(id) != null)
return getControl(id).isSessionComplete(p);
else return null;
@@ -411,7 +398,7 @@
/**
* @see com.evver.evvercards.service.Control#getSessionCount(Player)
*/
- public Integer getSessionCount(Player p) throws IllegalAccessException {
+ public Integer getSessionCount(Long id, Player p) throws IllegalAccessException {
if (getControl(id) != null)
return getControl(id).getSessionCount(p);
else return null;
@@ -420,7 +407,7 @@
/**
* @see com.evver.evvercards.service.Control#getSessionView(Player, String)
*/
- public View getSessionView(Player p, String userID) throws IllegalAccessException {
+ public View getSessionView(Long id, Player p, String userID) throws IllegalAccessException {
if (getControl(id) != null)
return getControl(id).getSessionView(p, userID);
else return null;
@@ -429,7 +416,7 @@
/**
* @see com.evver.evvercards.service.Control#getSessionState(Player)
*/
- public Integer getSessionState(Player p, String userID) throws IllegalAccessException {
+ public Integer getSessionState(Long id, Player p, String userID) throws IllegalAccessException {
if (getControl(id) != null)
return getControl(id).getSessionState(p, userID);
else return null;
@@ -439,7 +426,7 @@
/**
* @see com.evver.evvercards.service.Control#getSessionScore(Player, String)
*/
- public Score getSessionScore(Player p, String userID) throws IllegalAccessException {
+ public Score getSessionScore(Long id, Player p, String userID) throws IllegalAccessException {
if (getControl(id) != null)
return getControl(id).getSessionScore(p, userID);
else return null;
@@ -448,7 +435,7 @@
/**
* @see com.evver.evvercards.service.Control#getSessionScores(Player)
*/
- public List<Score> getSessionScores(Player p) throws IllegalAccessException {
+ public List<Score> getSessionScores(Long id, Player p) throws IllegalAccessException {
if (getControl(id) != null)
return getControl(id).getSessionScores(p);
else return null;
@@ -457,7 +444,7 @@
/**
* @see com.evver.evvercards.service.Control#getGameScore(Player, String)
*/
- public Score getGameScore(Player p, String userID) throws IllegalAccessException {
+ public Score getGameScore(Long id, Player p, String userID) throws IllegalAccessException {
if (getControl(id) != null)
return getControl(id).getGameScore(p, userID);
else return null;
@@ -466,7 +453,7 @@
/**
* @see com.evver.evvercards.service.Control#getGameScores(Player)
*/
- public List<Score> getGameScores(Player p) throws IllegalAccessException {
+ public List<Score> getGameScores(Long id, Player p) throws IllegalAccessException {
if (getControl(id) != null)
return getControl(id).getGameScores(p);
else return null;
@@ -475,7 +462,7 @@
/**
* @see com.evver.evvercards.service.Control#getCurrentUserID()
*/
- public String getCurrentUserID() throws IllegalAccessException {
+ public String getCurrentUserID(Long id) throws IllegalAccessException {
if (getControl(id) != null)
return getControl(id).getCurrentUserID();
else return null;
@@ -484,7 +471,7 @@
/**
* @see com.evver.evvercards.service.Control#getPlayers()
*/
- public List<Player> getPlayers() throws IllegalAccessException {
+ public List<Player> getPlayers(Long id) throws IllegalAccessException {
if (getControl(id) != null)
return getControl(id).getPlayers();
else return null;
Modified: evvercards/trunk/src/com/evver/evvercards/service/Service.java
===================================================================
--- evvercards/trunk/src/com/evver/evvercards/service/Service.java 2009-11-16 04:47:17 UTC (rev 777)
+++ evvercards/trunk/src/com/evver/evvercards/service/Service.java 2009-12-28 05:36:01 UTC (rev 778)
@@ -22,15 +22,336 @@
*/
package com.evver.evvercards.service;
+import java.util.List;
+import com.evver.evvercards.Card;
+import com.evver.evvercards.Description;
+import com.evver.evvercards.Player;
+import com.evver.evvercards.Position;
+import com.evver.evvercards.Score;
+import com.evver.evvercards.Status;
+import com.evver.evvercards.View;
+import com.evver.evvercards.events.Message;
+
+
/**
- * A service is a combination of a static game engine, and an instance
- * of a game control (one game control exists per game played). This combination
- * simplifies working with a control and engine, as only one engine ever exists
- * and multiple controls can coexist simultaneously.
+ * A service is a combination of a static game engine, and a simple access
+ * an instance of a game control (one game control exists per game played). This
+ * combination simplifies working with a control and engine, as only one engine ever
+ * exists and multiple controls can coexist simultaneously.
*
* Please see the AbstractService for a nearly complete implementation.
*
* @author ronald
*/
-public interface Service extends Control, Engine {}
\ No newline at end of file
+public interface Service extends Engine {
+
+ /**
+ * Gets the game description
+ * @param id the game id
+ * @return the game description
+ */
+ public Description getGameDescription(Long id);
+
+ /**
+ * Is the game started
+ * @param id the game id
+ * @return game started
+ */
+ public Boolean isGameStarted(Long id) throws IllegalAccessException;
+
+ /**
+ * Is the game complete
+ * @param id the game id
+ * @return game over
+ */
+ public Boolean isGameComplete(Long id) throws IllegalAccessException;
+
+ /**
+ * Gets the current player user ID
+ * @param id the game id
+ * @return the current player user name
+ */
+ public String getCurrentUserID(Long id) throws IllegalAccessException;
+
+ /**
+ * Gets the game players
+ * @param id the game id
+ * @return the game player user names
+ */
+ public List<Player> getPlayers(Long id) throws IllegalAccessException;
+
+
+ /**
+ * Requests the game or session to start
+ * @param id the game id
+ * @param p the player making the request
+ * @return request acknowledged
+ */
+ public Boolean start(Long id, Player p) throws IllegalAccessException;
+
+ /**
+ * Requests the game or session to end
+ * @param id the game id
+ * @param p the player making the request
+ * @return request acknowledged
+ */
+ public Boolean end(Long id, Player p) throws IllegalAccessException;
+
+ /**
+ * Gets the card at the top of the discard deck
+ * @param id the game id
+ * @param p the player making the request
+ * @return the discard top card
+ */
+ public Card getDiscardCard(Long id, Player p) throws IllegalAccessException;
+
+ /**
+ * Gets the card at the top of the source deck
+ * @param id the game id
+ * @param p the player making the request
+ * @return the source top card
+ */
+ public Card getSourceCard(Long id, Player p) throws IllegalAccessException;
+
+ /**
+ * Gets a list of held cards
+ * @param id the game id
+ * @param p the player
+ * @return a list of held cards
+ */
+ public List<Card> getHeldCards(Long id, Player p) throws IllegalAccessException;
+
+ /**
+ * Gets the card from player's board
+ * @param id the game id
+ * @param p the player
+ * @param pos the position
+ * @return the card
+ * @throws IllegalAccessException when player not authorized
+ */
+ public Card getBoardCard(Long id, Player p, Position pos)
+ throws IllegalAccessException;
+
+ /**
+ * Gets the position of the passed card
+ * @param id the game id
+ * @param p the player
+ * @param card the card
+ * @return the position of the card
+ * @throws IllegalAccessException when player not authorized
+ */
+ public Position getBoardPosition(Long id, Player p, Card card)
+ throws IllegalAccessException;
+
+ /**
+ * Gets the available positions on the players board
+ * @param id the game id
+ * @param p the player
+ * @return a list of available board positions
+ * @throws IllegalAccessException when player not authorized
+ */
+ public List<Position> getBoardPositions(Long id, Player p) throws IllegalAccessException;
+
+ /**
+ * Draws a card from the discard deck
+ * @param id the game id
+ * @param p the player to draw
+ * @return the card
+ * @throws IllegalAccessException when player not authorized
+ */
+ public Card drawFromDiscard(Long id, Player p) throws IllegalAccessException;
+
+ /**
+ * Draws a card from the source deck
+ * @param id the game id
+ * @param p the player
+ * @return the card
+ * @throws IllegalAccessException when player not authorized
+ */
+ public Card drawFromSource(Long id, Player p) throws IllegalAccessException;
+
+ /**
+ * Draws the desired card from the players hand
+ * @param id the game id
+ * @param p the player
+ * @param index the card index
+ * @return the card
+ * @throws IllegalAccessException when player not authorized
+ */
+ public Card drawFromHand(Long id, Player p, Integer index) throws IllegalAccessException;
+
+ /**
+ * Places a card for the player in the given position
+ * @param id the game id
+ * @param p the player
+ * @param pos the position
+ * @param card the card to place
+ * @return false if error encountered
+ * @throws IllegalAccessException when the player is not authorized
+ */
+ public Boolean playCard(Long id, Player p, Position pos, Card card)
+ throws IllegalAccessException;
+
+ /**
+ * Discards the given card
+ * @param id the game id
+ * @param p the player
+ * @param card the card to discard
+ * @return false if error encountered
+ * @throws IllegalAccessException when the player is not authorized
+ */
+ public Boolean discardCard(Long id, Player p, Card card) throws IllegalAccessException;
+
+ /**
+ * Holds the card in the players hand
+ * @param id the game id
+ * @param p the player
+ * @param card the card to hold
+ * @param index the position to hold the card
+ * @return false if error encountered
+ * @throws IllegalAccessException when the player is not authorized
+ */
+ public Boolean holdCard(Long id, Player p, Card card, Integer index) throws IllegalAccessException;
+
+ /**
+ * Reveals the card at the indicated position
+ * @param id the game id
+ * @param p the player
+ * @param pos the card position
+ * @return the revealed card
+ */
+ public Card revealCard(Long id, Player p, Position pos) throws IllegalAccessException;
+
+ /**
+ * Hides the card at the indicated position
+ * @param id the game id
+ * @param p the player
+ * @param pos the card position
+ * @return false if error encountered
+ * @throws IllegalAccessException when player is not authorized
+ */
+ public Boolean hideCard(Long id, Player p, Position pos) throws IllegalAccessException;
+
+ /**
+ * Is the position revealed
+ * @param id the game id
+ * @param p the player
+ * @param pos the card position
+ * @return position is revealed
+ */
+ public Boolean isPositionRevealed(Long id, Player p, Position pos) throws IllegalAccessException;
+
+ /**
+ * Is the position locked
+ * @param id the game id
+ * @param p the player
+ * @param pos the card position
+ * @return position is locked
+ */
+ public Boolean isPositionLocked(Long id, Player p, Position pos) throws IllegalAccessException;
+
+ /**
+ * Send the passed message to other players
+ * @param id the game id
+ * @param p the player
+ * @param m the message to send
+ * @return success sending message
+ */
+ public Boolean sendMessage(Long id, Player p, Message m) throws IllegalAccessException;
+
+ /**
+ * Send a generic game play signal
+ * @param id the game id
+ * @param p the player
+ * @param signal the signal object
+ * @return success sending signal
+ */
+ public Boolean sendSignal(Long id, Player p, Object signal) throws IllegalAccessException;
+
+ /**
+ * Is the current session initialized
+ * @param id the game id
+ * @return session is initialized
+ */
+ public Boolean isSessionInitialized(Long id, Player p) throws IllegalAccessException;
+
+ /**
+ * Is the current session complete
+ * @param id the game id
+ * @return session is complete
+ */
+ public Boolean isSessionComplete(Long id, Player p) throws IllegalAccessException;
+
+ /**
+ * Gets the number of sessions, including the current and all previous sessions
+ * @param id the game id
+ * @param p the player requesting the count
+ * @return the session count
+ */
+ public Integer getSessionCount(Long id, Player p) throws IllegalAccessException;
+
+ /**
+ * Gets the session view for the specified user name
+ * @param gid the game id
+ * @param p the requesting player
+ * @param pid the player id
+ * @return the user name view
+ */
+ public View getSessionView(Long gid, Player p, String pid) throws IllegalAccessException;
+
+ /**
+ * Gets the current session state
+ * @param gid the game id
+ * @param p the player make the request
+ * @param pid the player id
+ * @return the session state
+ */
+ public Integer getSessionState(Long gid, Player p, String pid) throws IllegalAccessException;
+
+ /**
+ * Gets the session score of a user
+ * @param gid the game id
+ * @param p the requesting player
+ * @param pid the player id
+ * @return the users score
+ */
+ public Score getSessionScore(Long gid, Player p, String pid) throws IllegalAccessException;
+
+ /**
+ * Gets the session score of all the players
+ * @param id the game id
+ * @param p the requesting player
+ * @return all players scores
+ * @throws IllegalAccessException
+ */
+ public List<Score> getSessionScores(Long id, Player p) throws IllegalAccessException;
+
+ /**
+ * Gets the game score for a user
+ * @param gid the game id
+ * @param p the requesting player
+ * @param pid the player id
+ * @return the game score
+ */
+ public Score getGameScore(Long gid, Player p, String pid) throws IllegalAccessException;
+
+ /**
+ * Gets the game score of all the players
+ * @param id the game id
+ * @param p the requesting player
+ * @return all players scores
+ * @throws IllegalAccessException
+ */
+ public List<Score> getGameScores(Long id, Player p) throws IllegalAccessException;
+
+ /**
+ * Gets the game status
+ * @param id the game id
+ * @param p the requesting player
+ * @return the game status
+ * @throws IllegalAccessException
+ */
+ public Status getGameStatus(Long id, Player p) throws IllegalAccessException;
+
+}
\ No newline at end of file
Modified: golfgame/trunk/src/com/evver/games/golf/simulate/Simulator.java
===================================================================
--- golfgame/trunk/src/com/evver/games/golf/simulate/Simulator.java 2009-11-16 04:47:17 UTC (rev 777)
+++ golfgame/trunk/src/com/evver/games/golf/simulate/Simulator.java 2009-12-28 05:36:01 UTC (rev 778)
@@ -73,17 +73,17 @@
joinGame(tom, gameId);
//Play the game
- playGame(bob);
+ playGame(gameId, bob);
//Get the score of each player
- Integer tomScore = getGameScore(tom, tom.getId()).getTotalScore();
- Integer sueScore = getGameScore(sue, sue.getId()).getTotalScore();
- Integer bobScore = getGameScore(bob, bob.getId()).getTotalScore();
+ Integer tomScore = getGameScore(gameId, tom, tom.getId()).getTotalScore();
+ Integer sueScore = getGameScore(gameId, sue, sue.getId()).getTotalScore();
+ Integer bobScore = getGameScore(gameId, bob, bob.getId()).getTotalScore();
//End the game for each player
- for (Player gp : getPlayers()) {
+ for (Player gp : getPlayers(gameId)) {
Player p = getPlayer(gp.getId());
- end(p);
+ end(gameId, p);
}
//Add to the total scores
@@ -129,31 +129,32 @@
/**
* Play a game
+ * @param id the game id
* @param player the lead player
*/
- private void playGame(Player player) {
+ private void playGame(Long id, Player player) {
//Start the game
try {
//Loop through simulated player moves
- while (!isGameComplete()) {
+ while (!isGameComplete(id)) {
//Start a new session each time the current is complete
- if (getCurrentUserID() == null) {
- for (Player gp : getPlayers()) {
+ if (getCurrentUserID(id) == null) {
+ for (Player gp : getPlayers(id)) {
Player p = getPlayer(gp.getId());
- start(p);
- AIUtils.initializePlayer(p, this);
+ start(id, p);
+ AIUtils.initializePlayer(p, getControl(id));
}
}
//Determine who has the control object
- String userID = getCurrentUserID();
+ String userID = getCurrentUserID(id);
Player p = getPlayer(userID);
//The player takes a turn
- AIUtils.smartPlayerMove(p, this);
+ AIUtils.smartPlayerMove(p, getControl(id));
}
} catch (IllegalAccessException e) {
This was sent by the SourceForge.net collaborative development platform, the world's largest Open Source development site.
|
|
From: A c. l. f. E. G. <evv...@li...> - 2009-11-16 04:47:23
|
Revision: 777
http://evvergames.svn.sourceforge.net/evvergames/?rev=777&view=rev
Author: rfulkerson
Date: 2009-11-16 04:47:17 +0000 (Mon, 16 Nov 2009)
Log Message:
-----------
Changed secured to reserved
Modified Paths:
--------------
evvercards/trunk/src/com/evver/evvercards/Description.java
evvercards/trunk/src/com/evver/evvercards/service/AbstractEngine.java
Modified: evvercards/trunk/src/com/evver/evvercards/Description.java
===================================================================
--- evvercards/trunk/src/com/evver/evvercards/service/AbstractEngine.java 2009-11-05 05:27:03 UTC (rev 776)
+++ evvercards/trunk/src/com/evver/evvercards/service/AbstractEngine.java 2009-11-16 04:47:17 UTC (rev 777)
@@ -101,7 +101,7 @@
//Do a security check
if (control != null && control.getGame() != null) {
Game game = control.getGame();
- if (game.getGameDescription().getSecured()) {
+ if (game.getGameDescription().getReserved()) {
AuthorizedDescription gd = (AuthorizedDescription) game.getGameDescription();
if (!gd.isPlayerAuthorized(p))
throw new IllegalAccessException(p + ", the supplied password is not correct");
This was sent by the SourceForge.net collaborative development platform, the world's largest Open Source development site.
|
|
From: A c. l. f. E. G. <evv...@li...> - 2009-11-05 05:27:14
|
Revision: 776
http://evvergames.svn.sourceforge.net/evvergames/?rev=776&view=rev
Author: rfulkerson
Date: 2009-11-05 05:27:03 +0000 (Thu, 05 Nov 2009)
Log Message:
-----------
Added favicon.ico
Added Paths:
-----------
evvermedia/trunk/media/web/avatars/favicon.ico
Added: evvermedia/trunk/media/web/avatars/favicon.ico
===================================================================
(Binary files differ)
Property changes on: evvermedia/trunk/media/web/avatars/favicon.ico
___________________________________________________________________
Added: svn:mime-type
+ application/octet-stream
This was sent by the SourceForge.net collaborative development platform, the world's largest Open Source development site.
|
|
From: A c. l. f. E. G. <evv...@li...> - 2009-11-05 05:26:06
|
Revision: 775
http://evvergames.svn.sourceforge.net/evvergames/?rev=775&view=rev
Author: rfulkerson
Date: 2009-11-05 05:26:00 +0000 (Thu, 05 Nov 2009)
Log Message:
-----------
Updated eclipse settings
Modified Paths:
--------------
evvercards/trunk/.settings/org.eclipse.jdt.core.prefs
Modified: evvercards/trunk/.settings/org.eclipse.jdt.core.prefs
===================================================================
--- evvercards/trunk/.settings/org.eclipse.jdt.core.prefs 2009-08-11 04:47:39 UTC (rev 774)
+++ evvercards/trunk/.settings/org.eclipse.jdt.core.prefs 2009-11-05 05:26:00 UTC (rev 775)
@@ -1,7 +1,12 @@
-#Wed Jul 04 10:22:33 PDT 2007
+#Mon Sep 14 20:39:14 PDT 2009
eclipse.preferences.version=1
+org.eclipse.jdt.core.compiler.codegen.inlineJsrBytecode=enabled
org.eclipse.jdt.core.compiler.codegen.targetPlatform=1.5
+org.eclipse.jdt.core.compiler.codegen.unusedLocal=preserve
org.eclipse.jdt.core.compiler.compliance=1.5
+org.eclipse.jdt.core.compiler.debug.lineNumber=generate
+org.eclipse.jdt.core.compiler.debug.localVariable=generate
+org.eclipse.jdt.core.compiler.debug.sourceFile=generate
org.eclipse.jdt.core.compiler.problem.assertIdentifier=error
org.eclipse.jdt.core.compiler.problem.enumIdentifier=error
org.eclipse.jdt.core.compiler.source=1.5
This was sent by the SourceForge.net collaborative development platform, the world's largest Open Source development site.
|
|
From: A c. l. f. E. G. <evv...@li...> - 2009-08-11 04:47:49
|
Revision: 774
http://evvergames.svn.sourceforge.net/evvergames/?rev=774&view=rev
Author: rfulkerson
Date: 2009-08-11 04:47:39 +0000 (Tue, 11 Aug 2009)
Log Message:
-----------
Added notes for compiling AS3
Modified Paths:
--------------
evvercards/trunk/README.txt
golfgame/trunk/README.txt
Modified: evvercards/trunk/README.txt
===================================================================
--- evvercards/trunk/README.txt 2009-08-11 04:37:59 UTC (rev 773)
+++ evvercards/trunk/README.txt 2009-08-11 04:47:39 UTC (rev 774)
@@ -11,6 +11,9 @@
The Evver Games project is designed to be built with Ant and Java 5 or
greater. To compile, ensure ant, java, and javac are on your PATH.
+If you desire to also compile the included AS3 classes, you must define
+FLEX_HOME and ensure FLEX_HOME/bin is on your PATH.
+
LICENSE:
Please see the accompanying LICENSE.txt file for more information on the
terms of the license.
Modified: golfgame/trunk/README.txt
===================================================================
--- golfgame/trunk/README.txt 2009-08-11 04:37:59 UTC (rev 773)
+++ golfgame/trunk/README.txt 2009-08-11 04:47:39 UTC (rev 774)
@@ -9,6 +9,9 @@
COMPILING:
The Evver Games project is designed to be built with Ant and Java 5 or
greater. To compile, ensure ant, java, and javac are on your PATH.
+
+If you desire to also compile the included AS3 classes, you must define
+FLEX_HOME and ensure FLEX_HOME/bin is on your PATH.
The included build file is designed to be aware of related Evver Games
sub-projects, and will build these automatically if they are present in
This was sent by the SourceForge.net collaborative development platform, the world's largest Open Source development site.
|
|
From: A c. l. f. E. G. <evv...@li...> - 2009-08-11 04:38:05
|
Revision: 773
http://evvergames.svn.sourceforge.net/evvergames/?rev=773&view=rev
Author: rfulkerson
Date: 2009-08-11 04:37:59 +0000 (Tue, 11 Aug 2009)
Log Message:
-----------
Fixed swc dependency
Modified Paths:
--------------
evvercards/trunk/build.xml
Modified: evvercards/trunk/build.xml
===================================================================
--- evvercards/trunk/build.xml 2009-08-11 04:32:01 UTC (rev 772)
+++ evvercards/trunk/build.xml 2009-08-11 04:37:59 UTC (rev 773)
@@ -58,7 +58,7 @@
</target>
<!-- Create evvercards swc library -->
- <target name="swc" depends="build">
+ <target name="swc" depends="init">
<!-- Define the component compiler task -->
<taskdef name="compc" classname="flex.ant.CompcTask" classpath="${FLEX_HOME}/ant/lib/flexTasks.jar" />
This was sent by the SourceForge.net collaborative development platform, the world's largest Open Source development site.
|
|
From: A c. l. f. E. G. <evv...@li...> - 2009-08-11 04:32:08
|
Revision: 772
http://evvergames.svn.sourceforge.net/evvergames/?rev=772&view=rev
Author: rfulkerson
Date: 2009-08-11 04:32:01 +0000 (Tue, 11 Aug 2009)
Log Message:
-----------
Added as3 support
Modified Paths:
--------------
golfgame/trunk/.classpath
golfgame/trunk/.settings/org.eclipse.wst.common.component
golfgame/trunk/CHANGELOG.txt
golfgame/trunk/build.xml
Modified: golfgame/trunk/.classpath
===================================================================
--- golfgame/trunk/.classpath 2009-08-11 04:30:51 UTC (rev 771)
+++ golfgame/trunk/.classpath 2009-08-11 04:32:01 UTC (rev 772)
@@ -1,6 +1,7 @@
<?xml version="1.0" encoding="UTF-8"?>
<classpath>
<classpathentry kind="src" path="src"/>
+ <classpathentry kind="src" path="as3"/>
<classpathentry kind="con" path="org.eclipse.jdt.launching.JRE_CONTAINER"/>
<classpathentry combineaccessrules="false" kind="src" path="/evvercards"/>
<classpathentry kind="output" path="bin"/>
Modified: golfgame/trunk/.settings/org.eclipse.wst.common.component
===================================================================
--- golfgame/trunk/.settings/org.eclipse.wst.common.component 2009-08-11 04:30:51 UTC (rev 771)
+++ golfgame/trunk/.settings/org.eclipse.wst.common.component 2009-08-11 04:32:01 UTC (rev 772)
@@ -2,5 +2,6 @@
<project-modules id="moduleCoreId" project-version="1.5.0">
<wb-module deploy-name="golfgame">
<wb-resource deploy-path="/" source-path="/src"/>
+ <wb-resource deploy-path="/" source-path="/as3"/>
</wb-module>
</project-modules>
Modified: golfgame/trunk/CHANGELOG.txt
===================================================================
--- golfgame/trunk/CHANGELOG.txt 2009-08-11 04:30:51 UTC (rev 771)
+++ golfgame/trunk/CHANGELOG.txt 2009-08-11 04:32:01 UTC (rev 772)
@@ -3,6 +3,7 @@
0.8 - In Development (Geeky Galvin)
Supports new EvverCards package
+Added as3 DAO classes
0.7 - October 29, 2007 (Freddie Freedom)
Supports option to load resources from an external URL
Modified: golfgame/trunk/build.xml
===================================================================
--- golfgame/trunk/build.xml 2009-08-11 04:30:51 UTC (rev 771)
+++ golfgame/trunk/build.xml 2009-08-11 04:32:01 UTC (rev 772)
@@ -11,6 +11,9 @@
<!-- Load the build.properties file -->
<property file="build.properties"/>
+ <!-- Set FLEX_HOME property -->
+ <property name="FLEX_HOME" value="${env.FLEX_HOME}"/>
+
<!-- Set the project classpath -->
<path id="golfgame.classpath">
<pathelement location="bin"/>
@@ -28,7 +31,7 @@
</target>
<!-- Build projects which golfgame depends upon -->
- <target name="build-subprojects" depends="init" if="evvercards.exists">
+ <target name="build-evvercards-jar" depends="init" if="evvercards.exists">
<ant antfile="${evvercards.location}/build.xml" target="jar" inheritAll="false">
<propertyset>
<propertyref name="build.compiler"/>
@@ -38,7 +41,7 @@
</target>
<!-- Build the golfgame and sub-projects -->
- <target name="build" depends="build-subprojects">
+ <target name="build" depends="build-evvercards-jar">
<echo message="${ant.project.name}: ${ant.file}"/>
<javac destdir="bin" debug="${debug}" debuglevel="${debuglevel}" source="${source}" target="${target}">
<src path="src"/>
@@ -66,8 +69,46 @@
<jar jarfile="dist/evvergames-golf.jar" manifest="bin/META-INF/MANIFEST.MF" basedir="bin"/>
</target>
+ <!-- Build projects which golfgame depends upon -->
+ <target name="build-evvercards-swc" depends="init" if="evvercards.exists">
+ <ant antfile="${evvercards.location}/build.xml" target="swc" inheritAll="false">
+ <propertyset>
+ <propertyref name="build.compiler"/>
+ </propertyset>
+ </ant>
+ <copy file="${evvercards.location}/dist/evvergames-cards.swc" tofile="lib/evvergames-cards.swc"/>
+ </target>
+
+
+ <!-- Create golfgame swc library -->
+ <target name="swc" depends="build-evvercards-swc">
+
+ <!-- Define the component compiler task -->
+ <taskdef name="compc" classname="flex.ant.CompcTask" classpath="${FLEX_HOME}/ant/lib/flexTasks.jar" />
+
+ <!-- Create a list of our classes -->
+ <pathconvert property="as3classes" pathsep=" ">
+ <fileset dir="${basedir}/as3/">
+ <include name="**/*.as"/>
+ <include name="**/*.mxml"/>
+ </fileset>
+ <compositemapper>
+ <packagemapper from="${basedir}\as3\*.as" to="*"/>
+ <packagemapper from="${basedir}/as3/*.as" to="*"/>
+ </compositemapper>
+ </pathconvert>
+
+ <!-- Compile the classes -->
+ <compc output="dist/evvergames-golf.swc" include-classes="${as3classes}">
+ <include-libraries dir="${basedir}/lib" append="true">
+ <include name="evvergames-cards.swc"/>
+ </include-libraries>
+ <source-path path-element="${basedir}/as3/"/>
+ </compc>
+ </target>
+
<!-- Create distribution release -->
- <target name="release" depends="jar">
+ <target name="release" depends="jar, swc">
<copy todir="dist" flatten="true" includeemptydirs="false">
<fileset dir="lib"/>
</copy>
@@ -75,7 +116,6 @@
excludes="**/.svn, bin/**, .settings/**, dist/evvergolf*.zip, .classpath, .project"/>
</target>
-
<!-- Clean the golfgame -->
<target name="clean">
<delete dir="bin"/>
This was sent by the SourceForge.net collaborative development platform, the world's largest Open Source development site.
|
|
From: A c. l. f. E. G. <evv...@li...> - 2009-08-11 04:30:59
|
Revision: 771
http://evvergames.svn.sourceforge.net/evvergames/?rev=771&view=rev
Author: rfulkerson
Date: 2009-08-11 04:30:51 +0000 (Tue, 11 Aug 2009)
Log Message:
-----------
Initial import
Added Paths:
-----------
golfgame/trunk/as3/
golfgame/trunk/as3/com/
golfgame/trunk/as3/com/evver/
golfgame/trunk/as3/com/evver/games/
golfgame/trunk/as3/com/evver/games/golf/
golfgame/trunk/as3/com/evver/games/golf/GolfView.as
golfgame/trunk/as3/com/evver/games/golf/simulate/
golfgame/trunk/as3/com/evver/games/golf/simulate/GolfPlayer.as
Added: golfgame/trunk/as3/com/evver/games/golf/GolfView.as
===================================================================
--- golfgame/trunk/as3/com/evver/games/golf/GolfView.as (rev 0)
+++ golfgame/trunk/as3/com/evver/games/golf/GolfView.as 2009-08-11 04:30:51 UTC (rev 771)
@@ -0,0 +1,37 @@
+/*
+ * Copyright (C) 2009 Ron Fulkerson. All Rights Reserved.
+ * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or (at
+ * your option) any later version. This file is subject to the "Classpath"
+ * exception as detailed in the LICENSE file that accompanied this code.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License along
+ * with this program; if not, write to the Free Software Foundation, Inc.,
+ * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+ *
+ * Please contact Ron Fulkerson [evvergames AT evver DOT com], or visit
+ * www.evver.com if you need additional information or have any questions.
+ */
+package com.evver.games.golf
+{
+
+ import com.evver.evvercards.Player;
+ import com.evver.evvercards.View;
+
+ [RemoteClass(alias="com.evver.games.golf.GolfView")]
+ public class GolfView extends View
+ {
+ public function GolfView(player:Player=null, cards:Object=null)
+ {
+ super(player, cards);
+ }
+ }
+}
\ No newline at end of file
Added: golfgame/trunk/as3/com/evver/games/golf/simulate/GolfPlayer.as
===================================================================
--- golfgame/trunk/as3/com/evver/games/golf/simulate/GolfPlayer.as (rev 0)
+++ golfgame/trunk/as3/com/evver/games/golf/simulate/GolfPlayer.as 2009-08-11 04:30:51 UTC (rev 771)
@@ -0,0 +1,36 @@
+/*
+ * Copyright (C) 2009 Ron Fulkerson. All Rights Reserved.
+ * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or (at
+ * your option) any later version. This file is subject to the "Classpath"
+ * exception as detailed in the LICENSE file that accompanied this code.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License along
+ * with this program; if not, write to the Free Software Foundation, Inc.,
+ * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+ *
+ * Please contact Ron Fulkerson [evvergames AT evver DOT com], or visit
+ * www.evver.com if you need additional information or have any questions.
+ */
+package com.evver.games.golf.simulate
+{
+ import com.evver.evvercards.Player;
+
+ [RemoteClass(alias="com.evver.games.golf.simulate.GolfPlayer")]
+ public class GolfPlayer extends Player
+ {
+ public function GolfPlayer(id:String=null, username:String=null)
+ {
+ super(id, username);
+ }
+
+ }
+}
\ No newline at end of file
This was sent by the SourceForge.net collaborative development platform, the world's largest Open Source development site.
|
|
From: A c. l. f. E. G. <evv...@li...> - 2009-08-11 04:06:48
|
Revision: 770
http://evvergames.svn.sourceforge.net/evvergames/?rev=770&view=rev
Author: rfulkerson
Date: 2009-08-11 04:06:40 +0000 (Tue, 11 Aug 2009)
Log Message:
-----------
Added getGameStatus()
Modified Paths:
--------------
evvercards/trunk/src/com/evver/evvercards/service/AbstractService.java
Modified: evvercards/trunk/src/com/evver/evvercards/service/AbstractService.java
===================================================================
--- evvercards/trunk/src/com/evver/evvercards/service/AbstractService.java 2009-08-11 03:56:54 UTC (rev 769)
+++ evvercards/trunk/src/com/evver/evvercards/service/AbstractService.java 2009-08-11 04:06:40 UTC (rev 770)
@@ -36,6 +36,7 @@
import com.evver.evvercards.Player;
import com.evver.evvercards.Position;
import com.evver.evvercards.Score;
+import com.evver.evvercards.Status;
import com.evver.evvercards.View;
import com.evver.evvercards.events.Event;
import com.evver.evvercards.events.EventListener;
@@ -217,6 +218,15 @@
return getControl(id).isGameComplete();
else return null;
}
+
+ /**
+ * @see com.evver.evvercards.service.Control#getGameStatus(Player)
+ */
+ public Status getGameStatus(Player p) throws IllegalAccessException {
+ if (getControl(id) != null) {
+ return getControl(id).getGameStatus(p);
+ } else return null;
+ }
/**
* @see com.evver.evvercards.service.Control#getDiscardCard()
This was sent by the SourceForge.net collaborative development platform, the world's largest Open Source development site.
|
|
From: A c. l. f. E. G. <evv...@li...> - 2009-08-11 03:57:00
|
Revision: 769
http://evvergames.svn.sourceforge.net/evvergames/?rev=769&view=rev
Author: rfulkerson
Date: 2009-08-11 03:56:54 +0000 (Tue, 11 Aug 2009)
Log Message:
-----------
Added as3 support
Modified Paths:
--------------
evvercards/trunk/.classpath
evvercards/trunk/.settings/org.eclipse.wst.common.component
Modified: evvercards/trunk/.classpath
===================================================================
--- evvercards/trunk/.classpath 2009-08-11 03:50:45 UTC (rev 768)
+++ evvercards/trunk/.classpath 2009-08-11 03:56:54 UTC (rev 769)
@@ -1,6 +1,7 @@
<?xml version="1.0" encoding="UTF-8"?>
<classpath>
<classpathentry kind="src" path="src"/>
+ <classpathentry kind="src" path="as3"/>
<classpathentry kind="con" path="org.eclipse.jdt.launching.JRE_CONTAINER"/>
<classpathentry kind="output" path="bin"/>
</classpath>
Modified: evvercards/trunk/.settings/org.eclipse.wst.common.component
===================================================================
--- evvercards/trunk/.settings/org.eclipse.wst.common.component 2009-08-11 03:50:45 UTC (rev 768)
+++ evvercards/trunk/.settings/org.eclipse.wst.common.component 2009-08-11 03:56:54 UTC (rev 769)
@@ -2,5 +2,6 @@
<project-modules id="moduleCoreId" project-version="1.5.0">
<wb-module deploy-name="evvercards">
<wb-resource deploy-path="/" source-path="/src"/>
+ <wb-resource deploy-path="/" source-path="/as3"/>
</wb-module>
</project-modules>
This was sent by the SourceForge.net collaborative development platform, the world's largest Open Source development site.
|
--- evvercards/trunk/src/com/evver/evvercards/Session.java 2009-12-28 05:43:49 UTC (rev 780)
+++ evvercards/trunk/src/com/evver/evvercards/Session.java 2009-12-29 06:04:24 UTC (rev 781)
@@ -32,7 +32,7 @@
//The session state constants
public static final int STATE_UNKNOWN = -1;
public static final int STATE_JOINED = 0;
- public static final int STATE_INITIALIZED = 1;
+ public static final int STATE_STARTED = 1;
public static final int STATE_COMPLETED = 2;
//The session fields
@@ -320,13 +320,13 @@
}
/**
* Gets the number of players who are initialized
* @return the number of initialized players
*/
- public int getInitializedCount() {
+ public int getStartedCount() {
int count = 0;
for (Integer i : states.values())
- if (i == STATE_INITIALIZED) count++;
+ if (i == STATE_STARTED) count++;
return count;
}
Modified: evvercards/trunk/src/com/evver/evvercards/service/AbstractControl.java
@@ -320,13 +320,13 @@
}
/**
- * Gets the number of players who are initialized
- * @return the number of initialized players
+ * Gets the number of players who have started
+ * @return the number of players who hae started
*/
===================================================================
--- evvercards/trunk/src/com/evver/evvercards/service/Control.java 2009-12-28 05:43:49 UTC (rev 780)
+++ evvercards/trunk/src/com/evver/evvercards/service/Control.java 2009-12-29 06:04:24 UTC (rev 781)
@@ -246,16 +246,16 @@
public Boolean sendSignal(Player p, Object signal) throws IllegalAccessException;
/**
* Is the current session initialized
* @return session is initialized
*/
- public Boolean isSessionInitialized(Player p) throws IllegalAccessException;
+ public Boolean isSessionStarted(Player p) throws IllegalAccessException;
/**
* Is the current session complete
* @return session is complete
*/
- public Boolean isSessionComplete(Player p) throws IllegalAccessException;
+ public Boolean isSessionCompleted(Player p) throws IllegalAccessException;
/**
* Gets the number of sessions, including the current and all previous sessions
Modified: evvercards/trunk/src/com/evver/evvercards/service/Service.java
@@ -246,16 +246,16 @@
public Boolean sendSignal(Player p, Object signal) throws IllegalAccessException;
/**
- * Is the current session initialized
- * @return session is initialized
+ * Is the current session started
+ * @return session is started
*/
===================================================================
--- golfgame/trunk/src/com/evver/games/golf/GolfControl.java 2009-12-28 05:43:49 UTC (rev 780)
+++ golfgame/trunk/src/com/evver/games/golf/GolfControl.java 2009-12-29 06:04:24 UTC (rev 781)
@@ -112,11 +112,11 @@
* @see com.evver.evvercards.service.Control#drawFromDiscard(Player)
*/
public synchronized Card drawFromDiscard(Player p) throws IllegalAccessException {
- if (getHeldCards(p).size() == 0 && isSessionInitialized(p)) {
+ if (getHeldCards(p).size() == 0 && isSessionStarted(p)) {
return super.drawFromDiscard(p);
- } else if (getHeldCards(p).size() == 0 && !isSessionInitialized(p)) {
+ } else if (getHeldCards(p).size() == 0 && !isSessionStarted(p)) {
throw new IllegalAccessException("Sorry " + p + ", but you must choose 2 cards first.");
- } else if (getHeldCards(p).size() > 0 && isSessionInitialized(p)) {
+ } else if (getHeldCards(p).size() > 0 && isSessionStarted(p)) {
throw new IllegalAccessException("Sorry " + p + ", but you must use the card you are holding.");
} else return null;
}
@@ -125,11 +125,11 @@
* @see com.evver.evvercards.service.Control#drawFromSource(Player)
*/
public synchronized Card drawFromSource(Player p) throws IllegalAccessException {
- if (getHeldCards(p).size() == 0 && isSessionInitialized(p)) {
+ if (getHeldCards(p).size() == 0 && isSessionStarted(p)) {
return super.drawFromSource(p);
- } else if (getHeldCards(p).size() == 0 && !isSessionInitialized(p)) {
+ } else if (getHeldCards(p).size() == 0 && !isSessionStarted(p)) {
throw new IllegalAccessException("Sorry " + p + ", but you must choose 2 cards first.");
- } else if (getHeldCards(p).size() > 0 && isSessionInitialized(p)) {
+ } else if (getHeldCards(p).size() > 0 && isSessionStarted(p)) {
throw new IllegalAccessException("Sorry " + p + ", but you must use the card you are holding.");
} else return null;
}
@@ -194,12 +194,12 @@
}
/**
- * @see com.evver.evvercards.service.Control#isSessionInitialized(com.evver.evvercards.Player)
+ * @see com.evver.evvercards.service.Control#isSessionStarted(com.evver.evvercards.Player)
*/
- public synchronized Boolean isSessionInitialized(Player p) throws IllegalAccessException {
+ public synchronized Boolean isSessionStarted(Player p) throws IllegalAccessException {
if (p.equals(getCurrentPlayer())) {
Session session = game.currentSession();
- if (session.getState(p) == Session.STATE_INITIALIZED) {
+ if (session.getState(p) == Session.STATE_STARTED) {
Board board = session.getBoard(p);
return new Boolean((board.getRevealedCount() >= 2) || (board.getLockedCount() >= 2));
} else return Boolean.FALSE;
@@ -219,13 +219,13 @@
Session session = game.currentSession();
//Create a new session when the current is complete
- if (isSessionComplete(session)) {
+ if (isSessionCompleted(session)) {
Player dealer = getNextPlayer(game.currentSession().getDealer());
session = createSession(dealer);
}
//Ensure the player has not already started
- if (session.getState(p) != Session.STATE_INITIALIZED) {
+ if (session.getState(p) != Session.STATE_STARTED) {
// Setup the player in the game
setupPlayer(p, session);
@@ -233,9 +233,9 @@
//Signal the player as ready
sendEvent(PLAYER_READY, p);
//Start the session and game, when all players are initialized
//NOTE: This will happen when the final player starts the game
- if (game.getPlayers().size() == session.getInitializedCount()) {
+ if (game.getPlayers().size() == session.getStartedCount()) {
//Ensure some competition - this will only happen once, since after
//that time the computer players will have already been added
@@ -277,7 +277,7 @@
if (getHeldCards(p).size() > 0) {
Card card = drawFromHand(p, 0);
discardCard(p, card);
- } else if (!isSessionInitialized(p)) {
+ } else if (!isSessionStarted(p)) {
revealCard(p, new Position(0, 0));
revealCard(p, new Position(0, 1));
discardCard(p, drawFromSource(p));
@@ -317,7 +317,7 @@
evaluateSession(game.currentSession());
// Is the session complete
- boolean sessionComplete = isSessionComplete(game.currentSession());
+ boolean sessionComplete = isSessionCompleted(game.currentSession());
//Send events when the session is complete
if (sessionComplete) {
Modified: golfgame/trunk/src/com/evver/games/golf/simulate/AIUtils.java
@@ -233,9 +233,9 @@
//Signal the player as ready
sendEvent(PLAYER_READY, p);
- //Start the session and game, when all players are initialized
+ //Start the session and game, when all players have started
//NOTE: This will happen when the final player starts the game
===================================================================
--- evvercards/trunk/src/com/evver/evvercards/Description.java 2009-11-05 05:27:03 UTC (rev 776)
+++ evvercards/trunk/src/com/evver/evvercards/Description.java 2009-11-16 04:47:17 UTC (rev 777)
@@ -35,7 +35,7 @@
private String title;
private String summary;
private Integer maxPlayers;
- private Boolean secured;
+ private Boolean reserved;
private Integer length;
private Long gameId;
@@ -60,7 +60,7 @@
this.summary = summary;
this.maxPlayers = max;
this.length = len;
- this.secured = false;
+ this.reserved = false;
this.gameId = null;
}
@@ -177,19 +177,19 @@
}
/**
* Is the game secured
* @return the game is secured
*/
- public Boolean getSecured() {
- return this.secured;
+ public Boolean getReserved() {
+ return this.reserved;
}
/**
* Sets this game as secured
* @param secured flag to set
*/
- public void setSecured(Boolean secured) {
- this.secured = secured;
+ public void setReserved(Boolean reserved) {
+ this.reserved = reserved;
}
}
Modified: evvercards/trunk/src/com/evver/evvercards/service/AbstractEngine.java
@@ -177,19 +177,19 @@
}
/**
- * Is the game secured
- * @return the game is secured
+ * Is the game reserved
+ * @return the game is reserved
*/
@@ -177,19 +177,19 @@
}
/**
- * Sets this game as secured
- * @param secured flag to set
+ * Sets this game as reserved
+ * @param reserved flag to set
*/
===================================================================